benchmark_regulatory_psites: benchmark_regulatory_psites

Description Usage Arguments Value

View source: R/benchmark.R

Description

This function check the coherence of regulatory phosphosites predicted by carniphal with ground truth from phosphositeplus

Usage

1

Arguments

sif

regulatory_psites, e.i. the first element of the list returned by regulatory_psites function

Value

a table comparing the predicted regulatory psites with the regulatory psites of phosphositeplus


saezlab/CARNIPHAL documentation built on Dec. 22, 2021, 9:12 p.m.