regulatory_psites: regulatory_psites

Description Usage Arguments Value

View source: R/benchmark.R

Description

This function extract regulatory phosphites from the carniphal network, e.i. psites that are differentially regulated on proteins that are found in the carniphal network

Usage

1
regulatory_psites(carniphal_res)

Arguments

carniphal_res

carnival result from the run_carnival function

Value

list with two elements: the regulatory psites with predicted mode of regulations and the kinases that catalyse their phosphorilation


saezlab/CARNIPHAL documentation built on Dec. 22, 2021, 9:12 p.m.