run_carniphal: Run CARNIPHAL

Description Usage Arguments Value

View source: R/run_carniphal.R

Description

This function runs CARNIVAL with the input of phosphoproteomic data (phosphosites and kinases). The prior knowledge network used is the combination of protein-protein and protein-phosphosite interactions from omnipath. Before running CARNIVAL the network is pruned by removing nodes n_steps upstream and downstream of measurements and inputs, respectively.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
run_carniphal(
  inputObj,
  measObj,
  netObj = carniphalPKN,
  rmNodes = NULL,
  pruning = TRUE,
  n_steps_pruning = 50,
  solverPath,
  solver = "cplex",
  timelimit = 7200,
  mipGAP = 0.05,
  poolrelGAP = 0
)

Arguments

inputObj

named vector of perturbation targets. Either 1 (up regulated) or -1 (down regulated)

measObj

named vector of the measurements

netObj

data frame of the prior knowledge network

rmNodes

character vector of nodes to remove from prior knowledge network

pruning

logic, set to TRUE if network should be pruned (recommended)

n_steps_pruning

integer giving the order of the neighborhood

solverPath

path to the solver

solver

one of the solvers available from getSupportedSolvers()

timelimit

solver time limit in seconds

mipGAP

CPLEX parameter: absolute tolerance on the gap

poolrelGAP

CPLEX/Cbc parameter: Allowed relative gap of accepted

Value

List of CARNIVAL results and final inputObj, measObj, netObj used


saezlab/CARNIPHAL documentation built on Dec. 22, 2021, 9:12 p.m.