Description Usage Arguments Value
This function check the coherence of regulatory phosphosites predicted by carniphal with ground truth from phosphositeplus
1 |
sif |
regulatory_psites, e.i. the first element of the list returned by regulatory_psites function |
a table comparing the predicted regulatory psites with the regulatory psites of phosphositeplus
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.