Description Usage Arguments Value
This function extract regulatory phosphites from the carniphal network, e.i. psites that are differentially regulated on proteins that are found in the carniphal network
1 | regulatory_psites(carniphal_res)
|
carniphal_res |
carnival result from the run_carnival function |
list with two elements: the regulatory psites with predicted mode of regulations and the kinases that catalyse their phosphorilation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.